@@ -1,12 +1,14 @@
 from datetime import datetime
 
 from django.db import models
-from django.db.models import permalink
+from django.urls import reverse
+
+from django_comments_xtd.moderation import moderator, XtdCommentModerator
 
 
 class PublicManager(models.Manager):
     """Returns published articles that are not in the future."""
-    
+
     def published(self):
         return self.get_query_set().filter(publish__lte=datetime.now())
 
@@ -26,13 +28,14 @@ class Article(models.Model):
         db_table = 'demo_articles'
         ordering = ('-publish',)
 
-    @permalink
     def get_absolute_url(self):
-        return ('articles-article-detail', None, 
-                {'year': self.publish.year,
-                 'month': int(self.publish.strftime('%m').lower()),
-                 'day': self.publish.day,
-                 'slug': self.slug})
+        return reverse(
+            'article-detail',
+            kwargs={'year': self.publish.year,
+                    'month': int(self.publish.strftime('%m').lower()),
+                    'day': self.publish.day,
+                    'slug': self.slug})
+
 
 class Diary(models.Model):
     """Diary, that accepts comments."""
@@ -46,3 +49,13 @@ class Diary(models.Model):
         db_table = 'demo_diary'
         ordering = ('-publish',)
 
+
+class DiaryCommentModerator(XtdCommentModerator):
+    email_notification = True
+    enable_field = 'allow_comments'
+    auto_moderate_field = 'publish'
+    moderate_after = 2
+    removal_suggestion_notification = True
+
+
+moderator.register(Diary, DiaryCommentModerator)
